@@ -186,13 +186,13 @@ flash_area (GtkWidget *widget)
 					       G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
 					       NULL,
 					       "org.gnome.Shell",
-					       "/org/gnome/Shell",
-					       "org.gnome.Shell",
+					       "/org/gnome/Shell/Screenshot",
+					       "org.gnome.Shell.Screenshot",
 					       NULL, NULL);
 	if (proxy == NULL)
 		g_warning ("no proxy");
 
-	g_dbus_proxy_call (proxy, "org.gnome.Shell.FlashArea",
+	g_dbus_proxy_call (proxy, "org.gnome.Shell.Screenshot.FlashArea",
 			   g_variant_new ("(iiii)", x, y, w, h),
 			   G_DBUS_CALL_FLAGS_NO_AUTO_START,
 			   -1,
@@ -331,7 +331,7 @@ impl_activate (PeasActivatable *plugin)
 	TotemScreenshotPlugin *self = TOTEM_SCREENSHOT_PLUGIN (plugin);
 	TotemScreenshotPluginPrivate *priv = self->priv;
 	const GtkActionEntry menu_entries[] = {
-		{ "take-screenshot", "camera-photo", N_("Take _Screenshot"), "<Ctrl><Primary>S", N_("Take a screenshot"), G_CALLBACK (take_screenshot_action_cb) },
+		{ "take-screenshot", "camera-photo", N_("Take _Screenshot"), "<Ctrl><Alt>S", N_("Take a screenshot"), G_CALLBACK (take_screenshot_action_cb) },
 		{ "take-gallery", NULL, N_("Create Screenshot _Gallery..."), NULL, N_("Create a gallery of screenshots"), G_CALLBACK (take_gallery_action_cb) }
 	};
 
