@@ -36,7 +36,7 @@
 #include "totem-interface.h"
 #include "totem-time-label.h"
 #include "bacon-video-widget.h"
-#include "gsd-media-keys-window.h"
+#include "gd-fullscreen-filter.h"
 
 #define FULLSCREEN_POPUP_TIMEOUT 5
 #define FULLSCREEN_MOTION_TIME 200 /* in milliseconds */
@@ -51,7 +51,6 @@ G_MODULE_EXPORT gboolean totem_fullscreen_vol_slider_pressed_cb (GtkWidget *widg
 G_MODULE_EXPORT gboolean totem_fullscreen_vol_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_pressed_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_seek_slider_released_cb (GtkWidget *widget, GdkEventButton *event, TotemFullscreen *fs);
-G_MODULE_EXPORT gboolean totem_fullscreen_motion_notify (GtkWidget *widget, GdkEventMotion *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_control_enter_notify (GtkWidget *widget, GdkEventCrossing *event, TotemFullscreen *fs);
 G_MODULE_EXPORT gboolean totem_fullscreen_control_leave_notify (GtkWidget *widget, GdkEventCrossing *event, TotemFullscreen *fs);
 
@@ -59,7 +58,6 @@ G_MODULE_EXPORT gboolean totem_fullscreen_control_leave_notify (GtkWidget *widge
 struct _TotemFullscreenPrivate {
 	BaconVideoWidget *bvw;
 	GtkWidget        *parent_window;
-	GtkWidget        *osd;
 
 	/* Fullscreen Popups */
 	GtkWidget        *exit_popup;
@@ -71,9 +69,9 @@ struct _TotemFullscreenPrivate {
 	guint             popup_timeout;
 	gboolean          popup_in_progress;
 	gboolean          pointer_on_control;
-	guint             motion_handler_id;
-	guint             motion_start_time;
-	guint             motion_num_events;
+	GdFullscreenFilter *filter;
+	gint64             motion_start_time;
+	guint              motion_num_events;
 
 	gboolean          is_fullscreen;
 
@@ -275,24 +273,25 @@ totem_fullscreen_popup_hide (TotemFullscreen *fs)
 	return FALSE;
 }
 
-G_MODULE_EXPORT gboolean
-totem_fullscreen_motion_notify (GtkWidget *widget,
-				GdkEventMotion *event,
-				TotemFullscreen *fs)
+static void
+totem_fullscreen_motion_notify (GdFullscreenFilter *filter,
+				TotemFullscreen    *fs)
 {
-	int motion_delay;
+	gint64 motion_delay;
+	gint64 curr;
 
+	curr = g_get_monotonic_time ();
 	/* Only after FULLSCREEN_MOTION_NUM_EVENTS motion events,
 	   in FULLSCREEN_MOTION_TIME milliseconds will we show
 	   the popups */
-	motion_delay = event->time - fs->priv->motion_start_time;
+	motion_delay = (curr - fs->priv->motion_start_time) / 1000;
 
 	if (fs->priv->motion_start_time == 0 ||
 	    motion_delay < 0 ||
 	    motion_delay > FULLSCREEN_MOTION_TIME) {
-		fs->priv->motion_start_time = event->time;
+		fs->priv->motion_start_time = curr;
 		fs->priv->motion_num_events = 0;
-		return FALSE;
+		return;
 	}
 
 	fs->priv->motion_num_events++;
@@ -301,8 +300,6 @@ totem_fullscreen_motion_notify (GtkWidget *widget,
 	    fs->priv->motion_num_events > FULLSCREEN_MOTION_NUM_EVENTS) {
 		totem_fullscreen_show_popups (fs, TRUE);
 	}
-
-	return FALSE;
 }
 
 void
@@ -349,37 +346,12 @@ totem_fullscreen_show_popups_or_osd (TotemFullscreen *fs,
 				     const char *icon_name,
 				     gboolean show_cursor)
 {
-	GtkAllocation allocation;
-	GdkScreen *screen;
-	GdkWindow *window;
-	GdkRectangle rect;
-	int monitor;
-
 	if (icon_name == NULL) {
 		totem_fullscreen_show_popups (fs, show_cursor);
 		return;
 	}
 
-	gtk_widget_get_allocation (GTK_WIDGET (fs->priv->bvw), &allocation);
-	gtk_window_resize (GTK_WINDOW (fs->priv->osd),
-			   allocation.height / 8,
-			   allocation.height / 8);
-
-	window = gtk_widget_get_window (GTK_WIDGET (fs->priv->bvw));
-	screen = gtk_widget_get_screen (GTK_WIDGET (fs->priv->bvw));
-	monitor = gdk_screen_get_monitor_at_window (screen, window);
-	gdk_screen_get_monitor_geometry (screen, monitor, &rect);
-
-	if (gtk_widget_get_direction (GTK_WIDGET (fs->priv->bvw)) == GTK_TEXT_DIR_RTL)
-		gtk_window_move (GTK_WINDOW (fs->priv->osd),
-				 rect.width - 8 - allocation.height / 8,
-				 rect.y + 8);
-	else
-		gtk_window_move (GTK_WINDOW (fs->priv->osd), rect.x + 8, rect.y + 8);
-
-	gsd_media_keys_window_set_action_custom (GSD_MEDIA_KEYS_WINDOW (fs->priv->osd),
-						 icon_name, FALSE);
-	gtk_widget_show (fs->priv->osd);
+	bacon_video_widget_popup_osd (fs->priv->bvw, icon_name);
 }
 
 G_MODULE_EXPORT gboolean
@@ -411,19 +383,13 @@ totem_fullscreen_set_fullscreen (TotemFullscreen *fs,
 
 	bacon_video_widget_set_fullscreen (fs->priv->bvw, fullscreen);
 	totem_fullscreen_set_cursor (fs, !fullscreen);
-	if (fullscreen == FALSE)
-		gtk_widget_hide (fs->priv->osd);
 
 	fs->priv->is_fullscreen = fullscreen;
 
-	if (fullscreen == FALSE && fs->priv->motion_handler_id != 0) {
-		g_signal_handler_disconnect (G_OBJECT (fs->priv->bvw),
-					     fs->priv->motion_handler_id);
-		fs->priv->motion_handler_id = 0;
-	} else if (fullscreen != FALSE && fs->priv->motion_handler_id == 0 && fs->priv->bvw != NULL) {
-		fs->priv->motion_handler_id = g_signal_connect (G_OBJECT (fs->priv->bvw), "motion-notify-event",
-								G_CALLBACK (totem_fullscreen_motion_notify), fs);
-	}
+	if (fullscreen == FALSE)
+		gd_fullscreen_filter_stop (fs->priv->filter);
+	else
+		gd_fullscreen_filter_start (fs->priv->filter);
 }
 
 static void
@@ -469,11 +435,14 @@ totem_fullscreen_new (GtkWindow *toplevel_window)
 
 	/* Volume */
 	fs->volume = GTK_WIDGET (gtk_builder_get_object (fs->priv->xml, "tcw_volume_button"));
-	
+
 	/* Seek */
 	fs->seek = GTK_WIDGET (gtk_builder_get_object (fs->priv->xml, "tcw_seek_hscale"));
 
 	/* Motion notify */
+	fs->priv->filter = gd_fullscreen_filter_new ();
+	g_signal_connect (G_OBJECT (fs->priv->filter), "motion-event",
+			  G_CALLBACK (totem_fullscreen_motion_notify), fs);
 	gtk_widget_add_events (fs->seek, GDK_POINTER_MOTION_MASK);
 	gtk_widget_add_events (fs->exit_button, GDK_POINTER_MOTION_MASK);
 
@@ -489,11 +458,6 @@ totem_fullscreen_set_video_widget (TotemFullscreen *fs,
 	g_return_if_fail (fs->priv->bvw == NULL);
 
 	fs->priv->bvw = bvw;
-
-	if (fs->priv->is_fullscreen != FALSE && fs->priv->motion_handler_id == 0) {
-		fs->priv->motion_handler_id = g_signal_connect (G_OBJECT (fs->priv->bvw), "motion-notify-event",
-								G_CALLBACK (totem_fullscreen_motion_notify), fs);
-	}
 }
 
 void
@@ -533,7 +497,6 @@ totem_fullscreen_init (TotemFullscreen *self)
 			  G_CALLBACK (totem_fullscreen_exit_popup_draw_cb), self);
 	self->priv->control_popup = GTK_WIDGET (gtk_builder_get_object (self->priv->xml,
 				"totem_controls_window"));
-	self->priv->osd = gsd_media_keys_window_new ();
 
 	/* Motion notify */
 	gtk_widget_add_events (self->priv->exit_popup, GDK_POINTER_MOTION_MASK);
@@ -561,15 +524,9 @@ totem_fullscreen_finalize (GObject *object)
         TotemFullscreen *fs = TOTEM_FULLSCREEN (object);
 
 	totem_fullscreen_popup_timeout_remove (fs);
-	if (fs->priv->motion_handler_id != 0) {
-		g_signal_handler_disconnect (G_OBJECT (fs->priv->bvw),
-					     fs->priv->motion_handler_id);
-		fs->priv->motion_handler_id = 0;
-	}
-
-	if (fs->priv->osd != NULL) {
-		gtk_widget_destroy (fs->priv->osd);
-		fs->priv->osd = NULL;
+	if (fs->priv->filter) {
+		g_object_unref (fs->priv->filter);
+		fs->priv->filter = NULL;
 	}
 
 	g_signal_handlers_disconnect_by_func (fs->priv->parent_window,
