@@ -23,7 +23,6 @@
 
 #include "config.h"
 #include "totem-playlist.h"
-#include "totemplaylist-marshal.h"
 
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
@@ -1656,7 +1655,6 @@ totem_playlist_init (TotemPlaylist *playlist)
 	playlist->priv->parser = totem_pl_parser_new ();
 
 	totem_pl_parser_add_ignored_scheme (playlist->priv->parser, "dvd:");
-	totem_pl_parser_add_ignored_scheme (playlist->priv->parser, "cdda:");
 	totem_pl_parser_add_ignored_scheme (playlist->priv->parser, "vcd:");
 	totem_pl_parser_add_ignored_scheme (playlist->priv->parser, "cd:");
 	totem_pl_parser_add_ignored_scheme (playlist->priv->parser, "dvb:");
@@ -2578,14 +2576,10 @@ totem_playlist_has_previous_mrl (TotemPlaylist *playlist)
 	if (update_current_from_playlist (playlist) == FALSE)
 		return FALSE;
 
-	if (playlist->priv->repeat != FALSE)
-		return TRUE;
-
-	if (playlist->priv->shuffle == FALSE)
-	{
+	if (playlist->priv->shuffle == FALSE) {
 		gtk_tree_model_get_iter (playlist->priv->model,
-				&iter,
-				playlist->priv->current);
+					 &iter,
+					 playlist->priv->current);
 
 		return gtk_tree_model_iter_previous (playlist->priv->model, &iter);
 	} else {
@@ -2606,14 +2600,10 @@ totem_playlist_has_next_mrl (TotemPlaylist *playlist)
 	if (update_current_from_playlist (playlist) == FALSE)
 		return FALSE;
 
-	if (playlist->priv->repeat != FALSE)
-		return TRUE;
-
-	if (playlist->priv->shuffle == FALSE)
-	{
+	if (playlist->priv->shuffle == FALSE) {
 		gtk_tree_model_get_iter (playlist->priv->model,
-				&iter,
-				playlist->priv->current);
+					 &iter,
+					 playlist->priv->current);
 
 		return gtk_tree_model_iter_next (playlist->priv->model, &iter);
 	} else {
@@ -2719,13 +2709,11 @@ totem_playlist_set_previous (TotemPlaylist *playlist)
 
 	totem_playlist_unset_playing (playlist);
 
-	if (playlist->priv->shuffle == FALSE)
-	{
+	if (playlist->priv->shuffle == FALSE) {
 		char *path;
 
 		path = gtk_tree_path_to_string (playlist->priv->current);
-		if (strcmp (path, "0") == 0)
-		{
+		if (g_str_equal (path, "0")) {
 			totem_playlist_set_at_end (playlist);
 			g_free (path);
 			return;
@@ -2736,7 +2724,8 @@ totem_playlist_set_previous (TotemPlaylist *playlist)
 				&iter,
 				playlist->priv->current);
 
-		gtk_tree_model_iter_previous (playlist->priv->model, &iter);
+		if (!gtk_tree_model_iter_previous (playlist->priv->model, &iter))
+			g_assert_not_reached ();
 		gtk_tree_path_free (playlist->priv->current);
 		playlist->priv->current = gtk_tree_model_get_path
 			(playlist->priv->model, &iter);
@@ -2775,7 +2764,8 @@ totem_playlist_set_next (TotemPlaylist *playlist)
 					 &iter,
 					 playlist->priv->current);
 
-		gtk_tree_model_iter_next (playlist->priv->model, &iter);
+		if (!gtk_tree_model_iter_next (playlist->priv->model, &iter))
+			g_assert_not_reached ();
 		gtk_tree_path_free (playlist->priv->current);
 		playlist->priv->current = gtk_tree_model_get_path (playlist->priv->model, &iter);
 	} else {
@@ -2990,7 +2980,7 @@ totem_playlist_class_init (TotemPlaylistClass *klass)
 				G_STRUCT_OFFSET (TotemPlaylistClass,
 					item_added),
 				NULL, NULL,
-				totemplaylist_marshal_VOID__STRING_STRING,
+				g_cclosure_marshal_generic,
 				G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 	totem_playlist_table_signals[ITEM_REMOVED] =
 		g_signal_new ("item-removed",
@@ -2999,6 +2989,6 @@ totem_playlist_class_init (TotemPlaylistClass *klass)
 				G_STRUCT_OFFSET (TotemPlaylistClass,
 					item_removed),
 				NULL, NULL,
-				totemplaylist_marshal_VOID__STRING_STRING,
+				g_cclosure_marshal_generic,
 				G_TYPE_NONE, 2, G_TYPE_STRING, G_TYPE_STRING);
 }
