@@ -845,14 +845,14 @@ create_gallery (ThumbApp *app)
 	/* Translators: The first string is "Filename" (as translated); the second is an actual filename.
 			The third string is "Resolution" (as translated); the fourth and fifth are screenshot height and width, respectively.
 			The sixth string is "Duration" (as translated); the seventh is the movie duration in words. */
-	header_text = g_strdup_printf (_("<b>%s</b>: %s\n<b>%s</b>: %d\303\227%d\n<b>%s</b>: %s"),
-				       _("Filename"),
-				       filename,
-				       _("Resolution"),
-				       screenshot_width,
-				       screenshot_height,
-				       _("Duration"),
-				       duration_text);
+	header_text = g_markup_printf_escaped (_("<b>%s</b>: %s\n<b>%s</b>: %d\303\227%d\n<b>%s</b>: %s"),
+					       _("Filename"),
+					       filename,
+					       _("Resolution"),
+					       screenshot_width,
+					       screenshot_height,
+					       _("Duration"),
+					       duration_text);
 	g_free (duration_text);
 	g_free (filename);
 
