@@ -32,6 +32,7 @@
 #include <glib-object.h>
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <locale.h>
 #include <string.h>
 
 #ifdef GDK_WINDOWING_X11
@@ -90,6 +91,7 @@ app_init (Totem *totem, char **argv)
 		totem_action_exit (NULL);
 
 	totem->win = GTK_WIDGET (gtk_builder_get_object (totem->xml, "totem_main_window"));
+	gtk_window_set_hide_titlebar_when_maximized (GTK_WINDOW (totem->win), TRUE);
 	g_object_bind_property (G_OBJECT (totem), "fullscreen",
 				G_OBJECT (totem->win), "show-menubar",
 				G_BINDING_INVERT_BOOLEAN);
@@ -234,6 +236,7 @@ main (int argc, char **argv)
 {
 	Totem *totem;
 
+	setlocale (LC_ALL, "");
 	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
